import { Component, OnDestroy, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { UserWatchListService } from '../entities/user-watch-list/user-watch-list.service';
import { IUserWatchList } from 'app/shared/model/user-watch-list.model';
import { AccountService } from 'app/core/auth/account.service';
import { Subscription } from 'rxjs';
import { Account } from 'app/core/user/account.model';


@Component({
    selector: 'jhi-watchlist',
    templateUrl: './watchlist.component.html',
    styleUrls: ['./watchlist.component.scss'],
})
export class WatchlistComponent implements OnInit, OnDestroy {

  account: Account | null = null;
  authSubscription?: Subscription;

    myWatchLists: IUserWatchList[] | undefined;

    constructor(
        protected watchListService: UserWatchListService,
        private accountService: AccountService,

    ) {
    }

    getMyWatchLists(): IUserWatchList[] {
        if(!this.isAuthenticated()) return [];
            if (!this.myWatchLists) {
            this.watchListService.findMyWatchlists().subscribe((data: HttpResponse<IUserWatchList[]>) => {
                if (data.body) {
                    this.myWatchLists = data.body;
                    /*
                    this.myWatchLists = [];
                    for (let i = 0; i < data.body.length; i++) {
                        this.myWatchLists.push(data.body[i]);
                    }
                    */
                }

            })
            return[]; 
        } else {
            return this.myWatchLists;
        }

    }

    ngOnInit(): void {
        this.authSubscription = this.accountService.getAuthenticationState().subscribe(account => (this.account = account));
    }

  isAuthenticated(): boolean {
    return this.accountService.isAuthenticated();
  }

  ngOnDestroy(): void {
    if (this.authSubscription) {
      this.authSubscription.unsubscribe();
    }
  }
}
